@@ -21,12 +21,13 @@ func TestDefaultDeployment(t *testing.T) {
 	var (
 		replicaCount int32 = 2
 		labels             = map[string]string{"app": api.OpenShiftConsoleName, "component": "ui"}
-		gracePeriod  int64 = 30
+		gracePeriod  int64 = 40
 	)
 	type args struct {
 		config             *operatorsv1.Console
 		cm                 *corev1.ConfigMap
 		ca                 *corev1.ConfigMap
+		dica               *corev1.ConfigMap
 		tca                *corev1.ConfigMap
 		sec                *corev1.Secret
 		rt                 *v1.Route
@@ -58,12 +59,13 @@ func TestDefaultDeployment(t *testing.T) {
 		DeletionGracePeriodSeconds: nil,
 		Labels:                     labels,
 		Annotations: map[string]string{
-			configMapResourceVersionAnnotation:          "",
-			secretResourceVersionAnnotation:             "",
-			serviceCAConfigMapResourceVersionAnnotation: "",
-			trustedCAConfigMapResourceVersionAnnotation: "",
-			proxyConfigResourceVersionAnnotation:        "",
-			consoleImageAnnotation:                      "",
+			configMapResourceVersionAnnotation:                   "",
+			secretResourceVersionAnnotation:                      "",
+			defaultIngressCertConfigMapResourceVersionAnnotation: "",
+			serviceCAConfigMapResourceVersionAnnotation:          "",
+			trustedCAConfigMapResourceVersionAnnotation:          "",
+			proxyConfigResourceVersionAnnotation:                 "",
+			consoleImageAnnotation:                               "",
 		},
 		OwnerReferences: nil,
 		Finalizers:      nil,
@@ -114,12 +116,13 @@ func TestDefaultDeployment(t *testing.T) {
 	}
 
 	consoleDeploymentTemplateAnnotations := map[string]string{
-		configMapResourceVersionAnnotation:          "",
-		secretResourceVersionAnnotation:             "",
-		serviceCAConfigMapResourceVersionAnnotation: "",
-		trustedCAConfigMapResourceVersionAnnotation: "",
-		proxyConfigResourceVersionAnnotation:        "",
-		consoleImageAnnotation:                      "",
+		configMapResourceVersionAnnotation:                   "",
+		secretResourceVersionAnnotation:                      "",
+		defaultIngressCertConfigMapResourceVersionAnnotation: "",
+		serviceCAConfigMapResourceVersionAnnotation:          "",
+		trustedCAConfigMapResourceVersionAnnotation:          "",
+		proxyConfigResourceVersionAnnotation:                 "",
+		consoleImageAnnotation:                               "",
 	}
 
 	consoleDeploymentAffinity := &corev1.Affinity{
@@ -162,7 +165,10 @@ func TestDefaultDeployment(t *testing.T) {
 				config: consoleOperatorConfig,
 				cm:     consoleConfig,
 				ca:     &corev1.ConfigMap{},
-				tca:    trustedCAConfigMapEmpty,
+				dica: &corev1.ConfigMap{
+					Data: map[string]string{"ca-bundle.crt": "test"},
+				},
+				tca: trustedCAConfigMapEmpty,
 				sec: &corev1.Secret{
 					TypeMeta:   metav1.TypeMeta{},
 					ObjectMeta: metav1.ObjectMeta{},
@@ -190,6 +196,7 @@ func TestDefaultDeployment(t *testing.T) {
 						Annotations: consoleDeploymentTemplateAnnotations,
 					},
 						Spec: corev1.PodSpec{
+							ServiceAccountName: "console",
 							// we want to deploy on master nodes
 							NodeSelector: map[string]string{
 								// empty string is correct
@@ -224,7 +231,10 @@ func TestDefaultDeployment(t *testing.T) {
 				config: consoleOperatorConfig,
 				cm:     consoleConfig,
 				ca:     &corev1.ConfigMap{},
-				tca:    trustedCAConfigMapSet,
+				dica: &corev1.ConfigMap{
+					Data: map[string]string{"ca-bundle.crt": "test"},
+				},
+				tca: trustedCAConfigMapSet,
 				sec: &corev1.Secret{
 					TypeMeta:   metav1.TypeMeta{},
 					ObjectMeta: metav1.ObjectMeta{},
@@ -252,6 +262,7 @@ func TestDefaultDeployment(t *testing.T) {
 						Annotations: consoleDeploymentTemplateAnnotations,
 					},
 						Spec: corev1.PodSpec{
+							ServiceAccountName: "console",
 							// we want to deploy on master nodes
 							NodeSelector: map[string]string{
 								// empty string is correct
@@ -283,7 +294,7 @@ func TestDefaultDeployment(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			if diff := deep.Equal(DefaultDeployment(tt.args.config, tt.args.cm, tt.args.cm, tt.args.tca, tt.args.sec, tt.args.rt, tt.args.proxy, tt.args.canMountCustomLogo), tt.want); diff != nil {
+			if diff := deep.Equal(DefaultDeployment(tt.args.config, tt.args.cm, tt.args.dica, tt.args.cm, tt.args.tca, tt.args.sec, tt.args.rt, tt.args.proxy, tt.args.canMountCustomLogo), tt.want); diff != nil {
 				t.Error(diff)
 			}
 		})
@@ -387,6 +398,19 @@ func Test_consoleVolumes(t *testing.T) {
 			},
 		},
 	}
+	defaultIngressCert := corev1.Volume{
+		Name: api.DefaultIngressCertConfigMapName,
+		VolumeSource: corev1.VolumeSource{
+			ConfigMap: &corev1.ConfigMapVolumeSource{
+				LocalObjectReference: corev1.LocalObjectReference{
+					Name: api.DefaultIngressCertConfigMapName,
+				},
+				Items:       nil,
+				DefaultMode: nil,
+				Optional:    nil,
+			},
+		},
+	}
 	tests := []struct {
 		name string
 		args args
@@ -402,6 +426,7 @@ func Test_consoleVolumes(t *testing.T) {
 				consoleOauthConfig,
 				consoleConfig,
 				serviceCA,
+				defaultIngressCert,
 			},
 		},
 		{
@@ -414,6 +439,7 @@ func Test_consoleVolumes(t *testing.T) {
 				consoleOauthConfig,
 				consoleConfig,
 				serviceCA,
+				defaultIngressCert,
 				{
 					Name: api.TrustedCAConfigMapName,
 					VolumeSource: corev1.VolumeSource{
@@ -479,6 +505,11 @@ func Test_consoleVolumeMounts(t *testing.T) {
 					ReadOnly:  true,
 					MountPath: "/var/service-ca",
 				},
+				{
+					Name:      api.DefaultIngressCertConfigMapName,
+					ReadOnly:  true,
+					MountPath: "/var/default-ingress-cert",
+				},
 			},
 		},
 		{name: "Test console volumes Mounts with TrustedCA",
@@ -506,6 +537,11 @@ func Test_consoleVolumeMounts(t *testing.T) {
 					ReadOnly:  true,
 					MountPath: "/var/service-ca",
 				},
+				{
+					Name:      api.DefaultIngressCertConfigMapName,
+					ReadOnly:  true,
+					MountPath: "/var/default-ingress-cert",
+				},
 				{
 					Name:      api.TrustedCAConfigMapName,
 					ReadOnly:  true,
